@@ -48,14 +48,7 @@ class CfnByteMatchSet(
         id: str,
         *,
         name: str,
-        byte_match_tuples: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]
-                ],
-            ]
-        ] = None,
+        byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::ByteMatchSet``.
 
@@ -68,34 +61,6 @@ class CfnByteMatchSet(
 
         jsii.create(CfnByteMatchSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnByteMatchSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -145,14 +110,7 @@ class CfnByteMatchSet(
     @jsii.member(jsii_name="byteMatchTuples")
     def byte_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -163,14 +121,7 @@ class CfnByteMatchSet(
     @byte_match_tuples.setter
     def byte_match_tuples(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]],
     ) -> None:
         jsii.set(self, "byteMatchTuples", value)
 
@@ -189,9 +140,7 @@ class CfnByteMatchSet(
         def __init__(
             self,
             *,
-            field_to_match: typing.Union[
-                aws_cdk.core.IResolvable, "CfnByteMatchSet.FieldToMatchProperty"
-            ],
+            field_to_match: typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.FieldToMatchProperty"],
             positional_constraint: str,
             text_transformation: str,
             target_string: typing.Optional[str] = None,
@@ -220,9 +169,7 @@ class CfnByteMatchSet(
         @builtins.property
         def field_to_match(
             self,
-        ) -> typing.Union[
-            aws_cdk.core.IResolvable, "CfnByteMatchSet.FieldToMatchProperty"
-        ]:
+        ) -> typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.FieldToMatchProperty"]:
             """``CfnByteMatchSet.ByteMatchTupleProperty.FieldToMatch``.
 
             see
@@ -337,17 +284,7 @@ class CfnByteMatchSetProps:
         self,
         *,
         name: str,
-        byte_match_tuples: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable,
-                        "CfnByteMatchSet.ByteMatchTupleProperty",
-                    ]
-                ],
-            ]
-        ] = None,
+        byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::ByteMatchSet``.
 
@@ -375,16 +312,7 @@ class CfnByteMatchSetProps:
     @builtins.property
     def byte_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -424,14 +352,7 @@ class CfnIPSet(
         id: str,
         *,
         name: str,
-        ip_set_descriptors: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]
-                ],
-            ]
-        ] = None,
+        ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::IPSet``.
 
@@ -444,34 +365,6 @@ class CfnIPSet(
 
         jsii.create(CfnIPSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnIPSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -521,14 +414,7 @@ class CfnIPSet(
     @jsii.member(jsii_name="ipSetDescriptors")
     def ip_set_descriptors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]]:
         """``AWS::WAF::IPSet.IPSetDescriptors``.
 
         see
@@ -539,14 +425,7 @@ class CfnIPSet(
     @ip_set_descriptors.setter
     def ip_set_descriptors(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "IPSetDescriptorProperty"]]]],
     ) -> None:
         jsii.set(self, "ipSetDescriptors", value)
 
@@ -581,6 +460,7 @@ class CfnIPSet(
             """
             ...
 
+
     class _IPSetDescriptorPropertyProxy:
         """
         see
@@ -620,16 +500,7 @@ class CfnIPSetProps:
         self,
         *,
         name: str,
-        ip_set_descriptors: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"
-                    ]
-                ],
-            ]
-        ] = None,
+        ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::IPSet``.
 
@@ -657,16 +528,7 @@ class CfnIPSetProps:
     @builtins.property
     def ip_set_descriptors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]]:
         """``AWS::WAF::IPSet.IPSetDescriptors``.
 
         see
@@ -707,14 +569,7 @@ class CfnRule(
         *,
         metric_name: str,
         name: str,
-        predicates: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]
-                ],
-            ]
-        ] = None,
+        predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::Rule``.
 
@@ -728,34 +583,6 @@ class CfnRule(
 
         jsii.create(CfnRule, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnRule":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -819,12 +646,7 @@ class CfnRule(
     @jsii.member(jsii_name="predicates")
     def predicates(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]]:
         """``AWS::WAF::Rule.Predicates``.
 
         see
@@ -835,14 +657,7 @@ class CfnRule(
     @predicates.setter
     def predicates(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PredicateProperty"]]]],
     ) -> None:
         jsii.set(self, "predicates", value)
 
@@ -927,14 +742,7 @@ class CfnRuleProps:
         *,
         metric_name: str,
         name: str,
-        predicates: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]
-                ],
-            ]
-        ] = None,
+        predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::Rule``.
 
@@ -973,14 +781,7 @@ class CfnRuleProps:
     @builtins.property
     def predicates(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]]:
         """``AWS::WAF::Rule.Predicates``.
 
         see
@@ -1020,12 +821,7 @@ class CfnSizeConstraintSet(
         id: str,
         *,
         name: str,
-        size_constraints: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]
-            ],
-        ],
+        size_constraints: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]]],
     ) -> None:
         """Create a new ``AWS::WAF::SizeConstraintSet``.
 
@@ -1038,34 +834,6 @@ class CfnSizeConstraintSet(
 
         jsii.create(CfnSizeConstraintSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnSizeConstraintSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1115,10 +883,7 @@ class CfnSizeConstraintSet(
     @jsii.member(jsii_name="sizeConstraints")
     def size_constraints(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]]]:
         """``AWS::WAF::SizeConstraintSet.SizeConstraints``.
 
         see
@@ -1129,12 +894,7 @@ class CfnSizeConstraintSet(
     @size_constraints.setter
     def size_constraints(
         self,
-        value: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]
-            ],
-        ],
+        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SizeConstraintProperty"]]],
     ) -> None:
         jsii.set(self, "sizeConstraints", value)
 
@@ -1202,9 +962,7 @@ class CfnSizeConstraintSet(
             self,
             *,
             comparison_operator: str,
-            field_to_match: typing.Union[
-                aws_cdk.core.IResolvable, "CfnSizeConstraintSet.FieldToMatchProperty"
-            ],
+            field_to_match: typing.Union[aws_cdk.core.IResolvable, "CfnSizeConstraintSet.FieldToMatchProperty"],
             size: jsii.Number,
             text_transformation: str,
         ) -> None:
@@ -1236,9 +994,7 @@ class CfnSizeConstraintSet(
         @builtins.property
         def field_to_match(
             self,
-        ) -> typing.Union[
-            aws_cdk.core.IResolvable, "CfnSizeConstraintSet.FieldToMatchProperty"
-        ]:
+        ) -> typing.Union[aws_cdk.core.IResolvable, "CfnSizeConstraintSet.FieldToMatchProperty"]:
             """``CfnSizeConstraintSet.SizeConstraintProperty.FieldToMatch``.
 
             see
@@ -1286,15 +1042,7 @@ class CfnSizeConstraintSetProps:
         self,
         *,
         name: str,
-        size_constraints: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable,
-                    "CfnSizeConstraintSet.SizeConstraintProperty",
-                ]
-            ],
-        ],
+        size_constraints: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSizeConstraintSet.SizeConstraintProperty"]]],
     ) -> None:
         """Properties for defining a ``AWS::WAF::SizeConstraintSet``.
 
@@ -1321,14 +1069,7 @@ class CfnSizeConstraintSetProps:
     @builtins.property
     def size_constraints(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnSizeConstraintSet.SizeConstraintProperty"
-            ]
-        ],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSizeConstraintSet.SizeConstraintProperty"]]]:
         """``AWS::WAF::SizeConstraintSet.SizeConstraints``.
 
         see
@@ -1368,16 +1109,7 @@ class CfnSqlInjectionMatchSet(
         id: str,
         *,
         name: str,
-        sql_injection_match_tuples: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"
-                    ]
-                ],
-            ]
-        ] = None,
+        sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::SqlInjectionMatchSet``.
 
@@ -1392,34 +1124,6 @@ class CfnSqlInjectionMatchSet(
 
         jsii.create(CfnSqlInjectionMatchSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnSqlInjectionMatchSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1469,14 +1173,7 @@ class CfnSqlInjectionMatchSet(
     @jsii.member(jsii_name="sqlInjectionMatchTuples")
     def sql_injection_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]]:
         """``AWS::WAF::SqlInjectionMatchSet.SqlInjectionMatchTuples``.
 
         see
@@ -1487,16 +1184,7 @@ class CfnSqlInjectionMatchSet(
     @sql_injection_match_tuples.setter
     def sql_injection_match_tuples(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"
-                    ]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "SqlInjectionMatchTupleProperty"]]]],
     ) -> None:
         jsii.set(self, "sqlInjectionMatchTuples", value)
 
@@ -1561,9 +1249,7 @@ class CfnSqlInjectionMatchSet(
         def __init__(
             self,
             *,
-            field_to_match: typing.Union[
-                aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.FieldToMatchProperty"
-            ],
+            field_to_match: typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.FieldToMatchProperty"],
             text_transformation: str,
         ) -> None:
             """
@@ -1581,9 +1267,7 @@ class CfnSqlInjectionMatchSet(
         @builtins.property
         def field_to_match(
             self,
-        ) -> typing.Union[
-            aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.FieldToMatchProperty"
-        ]:
+        ) -> typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.FieldToMatchProperty"]:
             """``CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty.FieldToMatch``.
 
             see
@@ -1625,17 +1309,7 @@ class CfnSqlInjectionMatchSetProps:
         self,
         *,
         name: str,
-        sql_injection_match_tuples: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable,
-                        "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty",
-                    ]
-                ],
-            ]
-        ] = None,
+        sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::SqlInjectionMatchSet``.
 
@@ -1663,17 +1337,7 @@ class CfnSqlInjectionMatchSetProps:
     @builtins.property
     def sql_injection_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable,
-                    "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty",
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]]:
         """``AWS::WAF::SqlInjectionMatchSet.SqlInjectionMatchTuples``.
 
         see
@@ -1715,14 +1379,7 @@ class CfnWebACL(
         default_action: typing.Union["WafActionProperty", aws_cdk.core.IResolvable],
         metric_name: str,
         name: str,
-        rules: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]
-                ],
-            ]
-        ] = None,
+        rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::WebACL``.
 
@@ -1742,34 +1399,6 @@ class CfnWebACL(
 
         jsii.create(CfnWebACL, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnWebACL":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1851,14 +1480,7 @@ class CfnWebACL(
     @jsii.member(jsii_name="rules")
     def rules(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]:
         """``AWS::WAF::WebACL.Rules``.
 
         see
@@ -1869,14 +1491,7 @@ class CfnWebACL(
     @rules.setter
     def rules(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]],
     ) -> None:
         jsii.set(self, "rules", value)
 
@@ -1891,9 +1506,7 @@ class CfnWebACL(
             *,
             priority: jsii.Number,
             rule_id: str,
-            action: typing.Optional[
-                typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable]
-            ] = None,
+            action: typing.Optional[typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable]] = None,
         ) -> None:
             """
             :param priority: ``CfnWebACL.ActivatedRuleProperty.Priority``.
@@ -1931,9 +1544,7 @@ class CfnWebACL(
         @builtins.property
         def action(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable]]:
             """``CfnWebACL.ActivatedRuleProperty.Action``.
 
             see
@@ -2004,21 +1615,10 @@ class CfnWebACLProps:
     def __init__(
         self,
         *,
-        default_action: typing.Union[
-            "CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable
-        ],
+        default_action: typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable],
         metric_name: str,
         name: str,
-        rules: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"
-                    ]
-                ],
-            ]
-        ] = None,
+        rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::WebACL``.
 
@@ -2070,16 +1670,7 @@ class CfnWebACLProps:
     @builtins.property
     def rules(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]]:
         """``AWS::WAF::WebACL.Rules``.
 
         see
@@ -2119,12 +1710,7 @@ class CfnXssMatchSet(
         id: str,
         *,
         name: str,
-        xss_match_tuples: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]
-            ],
-        ],
+        xss_match_tuples: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]]],
     ) -> None:
         """Create a new ``AWS::WAF::XssMatchSet``.
 
@@ -2137,34 +1723,6 @@ class CfnXssMatchSet(
 
         jsii.create(CfnXssMatchSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnXssMatchSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -2214,10 +1772,7 @@ class CfnXssMatchSet(
     @jsii.member(jsii_name="xssMatchTuples")
     def xss_match_tuples(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]]]:
         """``AWS::WAF::XssMatchSet.XssMatchTuples``.
 
         see
@@ -2228,12 +1783,7 @@ class CfnXssMatchSet(
     @xss_match_tuples.setter
     def xss_match_tuples(
         self,
-        value: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]
-            ],
-        ],
+        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "XssMatchTupleProperty"]]],
     ) -> None:
         jsii.set(self, "xssMatchTuples", value)
 
@@ -2298,9 +1848,7 @@ class CfnXssMatchSet(
         def __init__(
             self,
             *,
-            field_to_match: typing.Union[
-                aws_cdk.core.IResolvable, "CfnXssMatchSet.FieldToMatchProperty"
-            ],
+            field_to_match: typing.Union[aws_cdk.core.IResolvable, "CfnXssMatchSet.FieldToMatchProperty"],
             text_transformation: str,
         ) -> None:
             """
@@ -2318,9 +1866,7 @@ class CfnXssMatchSet(
         @builtins.property
         def field_to_match(
             self,
-        ) -> typing.Union[
-            aws_cdk.core.IResolvable, "CfnXssMatchSet.FieldToMatchProperty"
-        ]:
+        ) -> typing.Union[aws_cdk.core.IResolvable, "CfnXssMatchSet.FieldToMatchProperty"]:
             """``CfnXssMatchSet.XssMatchTupleProperty.FieldToMatch``.
 
             see
@@ -2359,14 +1905,7 @@ class CfnXssMatchSetProps:
         self,
         *,
         name: str,
-        xss_match_tuples: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnXssMatchSet.XssMatchTupleProperty"
-                ]
-            ],
-        ],
+        xss_match_tuples: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnXssMatchSet.XssMatchTupleProperty"]]],
     ) -> None:
         """Properties for defining a ``AWS::WAF::XssMatchSet``.
 
@@ -2393,14 +1932,7 @@ class CfnXssMatchSetProps:
     @builtins.property
     def xss_match_tuples(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnXssMatchSet.XssMatchTupleProperty"
-            ]
-        ],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnXssMatchSet.XssMatchTupleProperty"]]]:
         """``AWS::WAF::XssMatchSet.XssMatchTuples``.
 
         see
